# Kokam SLPB78205130H cell parameters

Parameters for a Kokam SLPB78205130H cell, from the paper

> Scott G. Marquis, Valentin Sulzer, Robert Timms, Colin P. Please, and S. Jon Chapman. "An asymptotic derivation of a single particle model with electrolyte." [arXiv preprint arXiv:1905.12553](https://arxiv.org/abs/1905.12553) (2019).

and references therein.
